@@ -279,8 +279,10 @@ file_notifier_traverse_tree (TrackerFileNotifier *notifier)
 		                              notifier);
 	}
 
-	/* We dispose regular files, only directories are cached */
-	tracker_file_system_delete_files (priv->file_system,
+	/* We dispose regular files here, only directories are cached once crawling
+	 * has completed.
+	 */
+	tracker_file_system_forget_files (priv->file_system,
 	                                  current_root,
 	                                  G_FILE_TYPE_REGULAR);
 
@@ -565,6 +567,7 @@ crawl_directories_start (TrackerFileNotifier *notifier)
 
 	while (priv->pending_index_roots) {
 		directory = priv->pending_index_roots->data;
+
 		tracker_indexing_tree_get_root (priv->indexing_tree,
 		                                directory,
 		                                &flags);
@@ -838,8 +841,8 @@ monitor_item_deleted_cb (TrackerMonitor *monitor,
 	g_signal_emit (notifier, signals[FILE_DELETED], 0, canonical);
 
 	if (is_directory) {
-		/* Delete all files underneath this dir from the filesystem */
-		tracker_file_system_delete_files (priv->file_system,
+		/* Remove all files underneath this dir from the cache */
+		tracker_file_system_forget_files (priv->file_system,
 						  file,
 						  G_FILE_TYPE_UNKNOWN);
 	}
@@ -1065,23 +1068,29 @@ indexing_tree_directory_removed (TrackerIndexingTree *indexing_tree,
 		g_signal_emit (notifier, signals[FILE_DELETED], 0, directory);
 	}
 
-	if (priv->pending_index_roots &&
-	    directory == priv->pending_index_roots->data) {
-		/* Directory being currently processed */
-		tracker_crawler_stop (priv->crawler);
-		g_cancellable_cancel (priv->cancellable);
+	if (priv->pending_index_roots) {
+		gboolean start_crawler = FALSE;
 
-		/* Remove index root and try the next one */
-		priv->pending_index_roots = g_list_delete_link (priv->pending_index_roots,
-		                                                priv->pending_index_roots);
-		crawl_directories_start (notifier);
+		if (directory == priv->pending_index_roots->data) {
+			/* Directory being currently processed */
+			tracker_crawler_stop (priv->crawler);
+			g_cancellable_cancel (priv->cancellable);
+			start_crawler = TRUE;
+		}
+
+		priv->pending_index_roots = g_list_remove_all (priv->pending_index_roots,
+		                                               directory);
+
+		if (start_crawler && priv->pending_index_roots != NULL) {
+			crawl_directories_start (notifier);
+		}
 	}
 
 	/* Remove monitors if any */
 	tracker_monitor_remove_recursively (priv->monitor, directory);
 
-	/* Remove all files from filesystem */
-	tracker_file_system_delete_files (priv->file_system, directory,
+	/* Remove all files from cache */
+	tracker_file_system_forget_files (priv->file_system, directory,
 	                                  G_FILE_TYPE_UNKNOWN);
 }
 
