@@ -1465,10 +1465,6 @@ main (int argc, char **argv)
 
 	g_type_init ();
 
-	if (!g_thread_supported ()) {
-		g_thread_init (NULL);
-	}
-
 
 #if HAVE_TRACKER_FTS
 	/* Only check stopwords if FTS is enabled */
